    {% extends '_base.html' -%}

    {% block banner -%}
    {% endblock -%}

    {% block mainpage -%}
    <div id="page-wrapper">
        <div class="divider"></div>
        <div class="12u">
            <div class="5grid-layout" id="onecolumn">
                <div class="row">
                    <div class="12u">
                        <section>
                        <div class="post">
                            {{ content }}
                        </div>
                        </section>
                    </div>
                </div>
            </div>
        </div>
    </div>
    {% endblock -%}